WalkDirection

Enum WalkDirection 

pub enum WalkDirection {
    None,
    Forward,
    Backward,
    Left,
    Right,
    ForwardRight,
    ForwardLeft,
    BackwardRight,
    BackwardLeft,
}
A direction that a player can walk in, including none.

Superset of SprintDirection.

This can be freely converted to and from DirectionStates.

Variants



None



Forward



Backward



Left



Right



ForwardRight



ForwardLeft



BackwardRight



BackwardLeft

Implementations

Source

impl WalkDirection

pub fn forward(self) -> bool

Returns true if the direction is forward, forward-right, or forward-left.

pub fn backward(self) -> bool

Returns true if the direction is backward, backward-right, or backward-left.

pub fn left(self) -> bool

Returns true if the direction is left, forward-left, or backward-left.

pub fn right(self) -> bool

Returns true if the direction is right, forward-right, or backward-right.

pub fn set_forward(&mut self, value: bool)

pub fn set_backward(&mut self, value: bool)

pub fn set_left(&mut self, value: bool)

pub fn set_right(&mut self, value: bool)

pub fn opposite(self) -> Self

Inverts the walk direction.

assert_eq!(WalkDirection::Forward.opposite(), WalkDirection::Backward);
assert_eq!(
    WalkDirection::BackwardRight.opposite(),
    WalkDirection::ForwardLeft
);
assert_eq!(WalkDirection::None.opposite(), WalkDirection::None);
Examples found in repository?
azalea/examples/testbot/commands/movement.rs (line 133)
127    fn walk_command(ctx: &Ctx, direction: WalkDirection) -> eyre::Result<i32> {
128        let mut seconds = get_float(ctx, "seconds").unwrap();
129        let source = ctx.source.lock();
130        let bot = source.bot.clone();
131
132        if seconds < 0. {
133            bot.walk(direction.opposite());
134            seconds = -seconds;
135        } else {
136            bot.walk(direction);
137        }
138
139        tokio::spawn(async move {
140            tokio::time::sleep(Duration::from_secs_f32(seconds)).await;
141            bot.walk(WalkDirection::None);
142        });
143        source.reply(format!("ok, walking {direction:?} for {seconds} seconds"));
144        Ok(1)
145    }